(function () {
  'use strict';

  ((once, $, Drupal, drupalSettings, debounce) => {

    function onInput(e) {
      debounce(saveTitle, 250)(e);
    }

    function saveTitle(e) {
      const layoutId = e.target.getAttribute('data-layout-id');
      Drupal.ajax({
        url: `${drupalSettings.path.baseUrl}${drupalSettings.path.pathPrefix}mercury-editor-inline-editor/${layoutId}/save-title`,
        submit: {
          value: e.target.textContent
        },
      }).execute();
    }

    function getEditableTitleElement(builderElement, settings) {
      const layoutId = builderElement.getAttribute('data-lpb-id');
      const layoutSettings = (settings.lpBuilder || {})[layoutId] || {};
      const editableTitleId = layoutSettings.editableTitleId;
      return document.querySelector(`[data-entity-title-editable-id="${editableTitleId}"]`);
    }

    function enableEditableTitle(builderElement, settings) {
      const layoutId = builderElement.getAttribute('data-lpb-id');
      const editableTitleElement = getEditableTitleElement(builderElement, settings);
      if (editableTitleElement) {
        editableTitleElement.setAttribute('data-layout-id', layoutId);
        editableTitleElement.setAttribute('contenteditable', true);
        editableTitleElement.addEventListener('input', onInput, false);
      }
    }

    function disableEditableTitle(builderElement, settings) {
      const editableTitleElement = getEditableTitleElement(builderElement, settings);
      if (editableTitleElement) {
        editableTitleElement.setAttribute('contenteditable', false);
        editableTitleElement.removeEventListener('input', onInput, false);
      }
    }

    Drupal.behaviors.layoutParagraphsInlineEditorEditableTitle = {
      attach: (context, settings) => {
        // Only run once.
        if (!once('editable-title', 'html').length) {
          return;
        }
        $(window).on('lpb-builder:open.lpb', (e) => {
          enableEditableTitle(e.target, settings);
        });
        $(window).on('lpb-builder:close.lpb', (e) => {
          disableEditableTitle(e.target, settings);
        });
      },
    };
  })(once, jQuery, Drupal, drupalSettings, Drupal.debounce);

})();
