((Drupal, drupalSettings, once) => {
  'use strict';
  /**
   * Uses window.postMessage() to send UI clicks to the parent window.
   *
   * @param Event e
   *   The click event.
   */
  function lpbClickHander(e) {
    // First, send the ajaxPageState to the parent window.
    window.parent.postMessage({
      type: 'ajaxPreviewPageState',
      settings: drupalSettings.ajaxPageState
    });
    // Then, send the click event.
    const message = {
      type: 'lpbUiClick',
      settings: {
        dialogType: e.currentTarget.getAttribute('data-dialog-type'),
        dialog: JSON.parse(e.currentTarget.getAttribute('data-dialog-options')),
        dialogRenderer: JSON.parse(e.currentTarget.getAttribute('data-dialog-renderer')),
        url: e.currentTarget.getAttribute('href'),
      }
    }
    if (message.settings.url.length > 0) {
      if (message.settings.url.indexOf('?') > -1) {
        message.settings.url += '&me_tray=true';
      }
      else {
        message.settings.url += '?me_tray=true';
      }
    }
    window.parent.postMessage(message);
    e.stopPropagation();
    return false;
  }

  /**
   * Attaches the behavior to the edit screen.
   */
  Drupal.behaviors.mercuryEditorPreviewScreen = {
    attach: function(context, _settings) {
      // Attaches click handlers to links that use window.postMessage().
      once('me-msg-broadcaster', '.use-postmessage').forEach((el) => {
        el.addEventListener('mousedown', lpbClickHander);
      });
      // Prevent links from working in iframe.
      if (window.parent !== window) {
        once('me-stop-iframed-links', 'a', context).forEach((link) => {
          if (link.closest('.lpb-controls') === null) {
            link.setAttribute('target', '_parent');
            link.addEventListener('click', (e) => {
              e.stopPropagation();
              e.preventDefault();
              return false;
            });
          }
        });
      }
    }
  }
})(Drupal, drupalSettings, once)
