<?php

namespace Drupal\mercury_editor\EventSubscriber;

use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\layout_paragraphs\Event\LayoutParagraphsAllowedTypesEvent;

/**
 * Class definition for LayoutParagraphsAllowedTypesSubcriber.
 */
class LayoutParagraphsAllowedTypesSubscriber implements EventSubscriberInterface {


  /**
   * The request stack service.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * Class constructor.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack service.
   */
  public function __construct(RequestStack $request_stack) {
    $this->request = $request_stack->getCurrentRequest();
  }

  /**
   * {@inheritDoc}
   */
  public static function getSubscribedEvents() {
    return [
      LayoutParagraphsAllowedTypesEvent::EVENT_NAME => 'alterUrls',
    ];
  }

  /**
   * Adds "mercury_editor" query parameter to component URLs.
   *
   * @param \Drupal\layout_paragraphs\Event\LayoutParagraphsAllowedTypesEvent $event
   *   The allowed types event.
   */
  public function alterUrls(LayoutParagraphsAllowedTypesEvent $event) {

    if ($this->request->query->get('me_tray')) {
      $types = $event->getTypes();
      foreach ($types as $type) {
        if ($type['url_object']) {
          $query_args = $type['url_object']->getOption('query');
          $query_args['me_tray'] = TRUE;
          $type['url_object']->setOption('query', $query_args);
        }
      }
      $event->setTypes($types);
    }

  }

}
