<?php

declare(strict_types=1);

namespace Drupal\mercury_editor\Plugin\StyleOption;

use Drupal\Core\Form\FormStateInterface;
use Drupal\style_options\Plugin\StyleOptionPluginBase;

/**
 * Define the class attribute option plugin.
 *
 * @StyleOption(
 *   id = "image_style",
 *   label = @Translation("Image style")
 * )
 */
class ImageStyle extends StyleOptionPluginBase {

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state): array {

    $element = [];
    $options = [];
    $plugin_id = $this->getPluginId();
    $styles = \Drupal::entityTypeManager()->getStorage('image_style')->loadMultiple();
    foreach ($styles as $style) {
      $options[$style->id()] = $style->label();
    }
    $value = $this->getValue($plugin_id) ?? $this->getDefaultValue() ?? key($options);
    $element['preview'] = [
      '#process' => [[$this, 'processPreview']],
      '#theme' => 'image_style_preview',
      '#style' => $styles[$value],
      '#all_styles' => $styles,
      '#prefix' => '<div id="image-style-preview">',
      '#suffix' => '</div>',
    ];
    $element[$plugin_id] = [
      '#type' => 'select',
      '#options' => $options,
      '#title' => $this->getLabel(),
      '#default_value' => $value,
      '#ajax' => [
        'callback' => [$this, 'ajaxCallback'],
        'wrapper' => 'image-style-preview',
      ],
    ];
    $element['#attached']['library'][] = 'image/admin';

    return $element;

    $form['property'] = [
      '#type' => 'textfield',
      '#title' => $this->getLabel(),
      '#default_value' => $this->getValue('property') ?? $this->getDefaultValue(),
      '#wrapper_attributes' => [
        'class' => [$this->getConfiguration()['property'] ?? ''],
      ],
      '#description' => $this->getConfiguration('description'),
    ];

    if ($this->hasConfiguration('options')) {
      $form['property']['#type'] = 'select';
      $options = $this->getConfiguration()['options'];

      if (
        class_exists('\Drupal\image_radios\Element\ImageRadios') &&
        count(array_filter($options, function ($option) {
          return isset($option['image']);
        }))) {

        $form['property']['#type'] = 'image_radios';
      }
      else {
        array_walk($options, function (&$option) {
          $option = $option['label'];
        });
        if ($this->hasConfiguration('multiple')) {
          $form['property']['#multiple'] = TRUE;
        }
      }

      $form['property']['#options'] = $options;
    }

    return $form;
  }

  public function processPreview($element, $form_state) {
    $path = $element['#parents'];
    array_pop($path);
    $path[] = 'image_style';
    if ($value = $form_state->getValue($path)) {
      $element['#style'] = $element['#all_styles'][$value];
    }
    return $element;
  }

  public function ajaxCallback($form, $form_state) {
    return $form['behavior_plugins']['style_options'][$this->getPluginId()]['preview'];
  }

  /**
   * {@inheritDoc}
   */
  public function build(array $build) {
    $plugin_id = $this->getPluginId();
    $value = $this->getValue($plugin_id) ?? NULL;
    $option_definition = $this->getConfiguration('options');
    if (is_array($value)) {
      $property = implode(' ',
        array_map(function ($index) use ($option_definition) {
          return $option_definition[$index]['value'] ?? NULL;
        }, $value)
      );
    }
    else {
      $property = $value ?? NULL;
    }
    if (!empty($property)) {
      $build['#' . $this->getOptionId()] = $property;
    }
    return $build;
  }

}
